@@ -71,6 +71,7 @@ class Py2NDevice:
                 name=info["deviceName"],
                 model=info["variant"],
                 serial=info["serialNumber"],
+                mac=info["macAddr"],
                 firmware=f"{info['swVersion']}-{info['buildType']}",
                 hardware=info["hwVersion"],
                 uptime=datetime.now(timezone.utc) - timedelta(seconds=status["upTime"]),
@@ -116,6 +117,9 @@ class Py2NDevice:
 
         return self._data.switches[switch_id - 1].active
 
+    async def close(self) -> None:
+        await self.aiohttp_session.close()
+
     @property
     def ip_address(self) -> str:
         """Device ip address."""
